==> elks-0.0.43snap.tar.gz: linuxmt/arch/i86/kernel/system.c <==
#include <linuxmt/types.h>
#include <linuxmt/sched.h>

#include <arch/segment.h>

__arch_mminit arch_segs;
int arch_cpu;			/* Processor type */

void setup_arch(start,end)
int *start;
int *end;
{
	int ct;
/*
 *	Save segments
 */
#asm
	mov bx, #_arch_segs
	mov ax, cs
	mov [bx], ax
	mov [bx+2], di
	mov ax, ss
	mov [bx+8], ax
	mov [bx+6], si
!	This is out of order to save a segment load and a few bytes :)
	mov ax, ds
	mov [bx+4], ax
	mov [bx+10], dx
	mov ds, ax
#endasm
	arch_segs.lowss = arch_segs.endss;
/*
 *	Detect processor [Rob de Bath]
 */
#asm
	mov	ax,#2
	push	sp
	pop	bx
	cmp	bx,sp
 	jz	ge286
	mov	cl,#32
	mov	ax,#1
	shl	ax,cl
	jmp	got_cpu
ge286:
	sub	sp,#6
	mov	bx,sp
!	seg	ss
 	sgdt	[bx]
	add	sp,#4
	pop	bx
	inc	bh
	jz	got_cpu
	mov	ax,#3
got_cpu:
	mov	_arch_cpu,ax
#endasm
	
	/*
	 *	Now create task 0 to be ourself. Set the kernel SP,
	 *	as we will need this in interrupts.
	 */	

 	task[0].state = TASK_RUNNING;
	task[0].t_count=0;
	task[0].t_priority=0;
	task[0].t_regs.ksp=&task[0].t_kstack+126;
	task[0].t_priority=10;
	task[0].t_count=0;
	task[0].t_regs.ds=get_ds();	/* Run in kernel space */
	
	current = &task[0];
	curnum = 0;
	
	/*
	 *	Mark tasks 1-31 as not in use.
	 */
	for(ct=1;ct<MAX_TASKS;ct++)
		task[ct].state=TASK_UNUSED;
	/*
	 *	Fill in the MM numbers - really ought to be in mm not kernel ?
	 *	640K base mem is still hard coded (messy)
	 */
	 
	*end = 640<<6;		/* 640K in 16 byte blocks expressed to stay in an int */
	*start = get_ds();
	*start += ((unsigned int)(_endbss+15))>>4;
}

==> elks-0.0.44snap.tar.gz: linuxmt/arch/i86/kernel/system.c <==
#include <linuxmt/types.h>
#include <linuxmt/sched.h>

#include <arch/segment.h>

__arch_mminit arch_segs;
int arch_cpu;			/* Processor type */

void setup_arch(start,end)
int *start;
int *end;
{
	int ct;
/*
 *	Save segments
 */
#asm
	mov bx, #_arch_segs
	mov ax, cs
	mov [bx], ax
	mov [bx+2], di
	mov ax, ss
	mov [bx+8], ax
	mov [bx+6], si
!	This is out of order to save a segment load and a few bytes :)
	mov ax, ds
	mov [bx+4], ax
	mov [bx+10], dx
	mov ds, ax
#endasm
	arch_segs.lowss = arch_segs.endss;
/*
 *	Detect processor [Rob de Bath]
 */
#asm
	mov	ax,#2
	push	sp
	pop	bx
	cmp	bx,sp
 	jz	ge286
	mov	cl,#32
	mov	ax,#1
	shl	ax,cl
	jmp	got_cpu
ge286:
	sub	sp,#6
	mov	bx,sp
!	seg	ss
 	sgdt	[bx]
	add	sp,#4
	pop	bx
	inc	bh
	jz	got_cpu
	mov	ax,#3
got_cpu:
	mov	_arch_cpu,ax
#endasm
	
	/*
	 *	Now create task 0 to be ourself. Set the kernel SP,
	 *	as we will need this in interrupts.
	 */	

 	task[0].state = TASK_RUNNING;
	task[0].t_count=0;
	task[0].t_priority=0;
	task[0].t_regs.ksp=task[0].t_kstack+KSTACK_BYTES;
	task[0].t_priority=10;
	task[0].t_count=0;
	task[0].t_regs.ds=get_ds();	/* Run in kernel space */
	
	current = &task[0];
	curnum = 0;
	
	/*
	 *	Mark tasks 1-31 as not in use.
	 */
	for(ct=1;ct<MAX_TASKS;ct++)
		task[ct].state=TASK_UNUSED;
	/*
	 *	Fill in the MM numbers - really ought to be in mm not kernel ?
	 *	640K base mem is still hard coded (messy)
	 */
	 
	*end = 640<<6;		/* 640K in 16 byte blocks expressed to stay in an int */
	*start = get_ds();
	*start += ((unsigned int)(_endbss+15))>>4;
}
